# Nanpy firmware v0.9.4

[![Travis](http://img.shields.io/travis/nanpy/nanpy-firmware.svg)] (https://travis-ci.org/nanpy/nanpy-firmware)

Firmware for Nanpy, a library to use your Arduino board with Python. Read more on Nanpy at https://github.com/nanpy

## How to configure

	$ cd firmware
	$ ./configure.sh

You can use Nanpy/cfg.h generated file to configure your Nanpy firmware, selecting the features you want to include and the baud rate.

## How to build and install

Copy Nanpy directory under your "sketchbook" directory, start your Arduino IDE, open Sketchbook/Nanpy, select "Upload".

## License

This software is released under MIT License. Copyright (c) 2012-2015 Andrea Stagi <stagi.andrea@gmail.com>
